Module: ActsAsMarkup::ActiveRecordExtension::ClassMethods
- Defined in:
- lib/acts_as_markup/active_record_extension.rb
Instance Method Summary collapse
-
#acts_as_markdown(*columns) ⇒ Object
This is a convenience method for
<tt>acts_as_markup :language => :markdown, :columns => [:body]</tt>Additional options can be given at the end, if necessary. -
#acts_as_markup(options) ⇒ Object
This allows you to specify columns you want to define as containing Markdown, Textile, or RDoc content.
-
#acts_as_rdoc(*columns) ⇒ Object
This is a convenience method for
<tt>acts_as_markup :language => :rdoc, :columns => [:body]</tt>Additional options can be given at the end, if necessary. -
#acts_as_textile(*columns) ⇒ Object
This is a convenience method for
<tt>acts_as_markup :language => :textile, :columns => [:body]</tt>Additional options can be given at the end, if necessary.
Instance Method Details
#acts_as_markdown(*columns) ⇒ Object
This is a convenience method for
<tt>acts_as_markup :language => :markdown, :columns => [:body]</tt>
Additional options can be given at the end, if necessary.
83 84 85 86 |
# File 'lib/acts_as_markup/active_record_extension.rb', line 83 def acts_as_markdown(*columns) = columns. acts_as_markup .merge(:language => :markdown, :columns => columns) end |
#acts_as_markup(options) ⇒ Object
This allows you to specify columns you want to define as containing Markdown, Textile, or RDoc content. Then you can simply call .to_html method on the attribute.
You can also specify the language as :variable. The language used to process the column will be based on another column. By default a column named "markup_language" is used, but this can be changed by providing a :language_column option. When a value is accessed it will create the correct object (Markdown, Textile, or RDoc) based on the value of the language column. If any value besides markdown, textile, or RDoc is supplied for the markup language the text will pass through as a string.
You can specify additional options to pass to the markup library by using :markdown_options, :textile_options . RDoc does not support any useful options. The options should be given as an array of arguments. You can specify options for more than one language when using :variable. See each library's documentation for more details on what options are available.
Examples
Using Markdown language
class Post < ActiveRecord
acts_as_markup :language => :markdown, :columns => [:body]
end
@post = Post.find(:first)
@post.body.to_s # => "## Markdown Headline"
@post.body.to_html # => "<h2> Markdown Headline</h2>"
Using variable language
class Post < ActiveRecord
acts_as_markup :language => :variable, :columns => [:body], :language_column => 'language_name'
end
@post = Post.find(:first)
@post.language_name # => "markdown"
@post.body.to_s # => "## Markdown Headline"
@post.body.to_html # => "<h2> Markdown Headline</h2>"
Using options
class Post < ActiveRecord
acts_as_markup :language => :markdown, :columns => [:body], :markdown_options => [ :filter_html ]
end
class Post < ActiveRecord
acts_as_markup :language => :textile, :columns => [:body], :textile_options => [ [ :filter_html ] ]
end
67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/acts_as_markup/active_record_extension.rb', line 67 def acts_as_markup() .reverse_merge!(:language_column => :markup_language) include InstanceMethods unless [:language].to_sym == :variable define_markup_columns_reader_methods() else define_variable_markup_columns_reader_methods() end end |
#acts_as_rdoc(*columns) ⇒ Object
This is a convenience method for
<tt>acts_as_markup :language => :rdoc, :columns => [:body]</tt>
Additional options can be given at the end, if necessary.
101 102 103 104 |
# File 'lib/acts_as_markup/active_record_extension.rb', line 101 def acts_as_rdoc(*columns) = columns. acts_as_markup .merge(:language => :rdoc, :columns => columns) end |
#acts_as_textile(*columns) ⇒ Object
This is a convenience method for
<tt>acts_as_markup :language => :textile, :columns => [:body]</tt>
Additional options can be given at the end, if necessary.
92 93 94 95 |
# File 'lib/acts_as_markup/active_record_extension.rb', line 92 def acts_as_textile(*columns) = columns. acts_as_markup .merge(:language => :textile, :columns => columns) end |